Documentation
¶
Index ¶
- Variables
- type Log
- func (l *Log) Debug(args ...interface{})
- func (l *Log) Debugf(template string, args ...interface{})
- func (l *Log) Error(args ...interface{})
- func (l *Log) Errorf(template string, args ...interface{})
- func (l *Log) Fatal(args ...interface{})
- func (l *Log) Fatalf(template string, args ...interface{})
- func (l *Log) Warnf(template string, args ...interface{})
- type Logger
Constants ¶
This section is empty.
Variables ¶
var DefaultLogger = &Log{}
Functions ¶
This section is empty.
Types ¶
type Log ¶
type Log struct {
}
Log is just a dummy log tool that you can use. for more advenced usage please use Zap or Logrus.
type Logger ¶
type Logger interface {
Debug(args ...interface{})
Debugf(template string, args ...interface{})
Error(args ...interface{})
Errorf(template string, args ...interface{})
Fatal(args ...interface{})
Fatalf(template string, args ...interface{})
Warnf(template string, args ...interface{})
}
Logger is an interface for using your own Logging tool like Zap or Logrus.
Click to show internal directories.
Click to hide internal directories.